"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const visitor_plugin_common_1 = require("@graphql-codegen/visitor-plugin-common");
const testing_1 = require("@graphql-codegen/testing");
const index_1 = require("../src/index");
const graphql_1 = require("graphql");
const plugin_helpers_1 = require("@graphql-codegen/plugin-helpers");
const typescript_1 = require("@graphql-codegen/typescript");
const typescript_operations_1 = require("@graphql-codegen/typescript-operations");
describe('graphql-request', () => {
    const schema = graphql_1.buildClientSchema(require('../dev-test/githunt/schema.json'));
    const basicDoc = graphql_1.parse(/* GraphQL */ `
    query feed {
      feed {
        id
        commentCount
        repository {
          owner {
            avatar_url
          }
        }
      }
    }

    query feed2($v: String!) {
      feed {
        id
      }
    }

    query feed3($v: String) {
      feed {
        id
      }
    }

    query feed4($v: String! = "TEST") {
      feed {
        id
      }
    }
  `);
    const validate = (content, config, docs, pluginSchema, usage) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const m = plugin_helpers_1.mergeOutputs([
            yield typescript_1.plugin(pluginSchema, docs, config, { outputFile: '' }),
            yield typescript_operations_1.plugin(pluginSchema, docs, config),
            content,
            usage,
        ]);
        yield testing_1.validateTs(m);
        return m;
    });
    describe('sdk', () => {
        it('Should generate a correct wrap method', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            const config = {};
            const docs = [{ location: '', document: basicDoc }];
            const result = (yield index_1.plugin(schema, docs, config, {
                outputFile: 'graphql.ts',
            }));
            const usage = `
async function test() {
  const client = new GraphQLClient('');
  const sdk = getSdk(client);
  
  await sdk.feed();
  await sdk.feed3();
  await sdk.feed4();

  const result = await sdk.feed2({ v: "1" });

  if (result.feed) {
    if (result.feed[0]) {
      const id = result.feed[0].id
    }
  }
}`;
            const output = yield validate(result, config, docs, schema, usage);
            expect(output).toMatchSnapshot();
        }));
        it('Should generate a correct wrap method with documentMode=string', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            const config = { documentMode: visitor_plugin_common_1.DocumentMode.string };
            const docs = [{ location: '', document: basicDoc }];
            const result = (yield index_1.plugin(schema, docs, config, {
                outputFile: 'graphql.ts',
            }));
            const usage = `
async function test() {
  const client = new GraphQLClient('');
  const sdk = getSdk(client);
  
  await sdk.feed();
  await sdk.feed3();
  await sdk.feed4();

  const result = await sdk.feed2({ v: "1" });

  if (result.feed) {
    if (result.feed[0]) {
      const id = result.feed[0].id
    }
  }
}`;
            const output = yield validate(result, config, docs, schema, usage);
            expect(output).toMatchSnapshot();
        }));
        it('Should allow passing wrapper arg to generated getSdk', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            const config = { documentMode: visitor_plugin_common_1.DocumentMode.string };
            const docs = [{ location: '', document: basicDoc }];
            const result = (yield index_1.plugin(schema, docs, config, {
                outputFile: 'graphql.ts',
            }));
            const usage = `
async function test() {
  const client = new GraphQLClient('');
  const functionWrapper: SdkFunctionWrapper = async <T>(action: () => Promise<T>): Promise<T> => {
    console.log('before');
    const result = await action();
    console.log('after');
    return result;
  }

  const sdk = getSdk(client, functionWrapper);
  
  await sdk.feed();
  await sdk.feed3();
  await sdk.feed4();

  const result = await sdk.feed2({ v: "1" });

  if (result.feed) {
    if (result.feed[0]) {
      const id = result.feed[0].id
    }
  }
}`;
            const output = yield validate(result, config, docs, schema, usage);
            expect(output).toMatchSnapshot();
        }));
        it('Should support useTypeImports', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            const config = { useTypeImports: true };
            const docs = [{ location: '', document: basicDoc }];
            const result = (yield index_1.plugin(schema, docs, config, {
                outputFile: 'graphql.ts',
            }));
            const usage = `
async function test() {
  const client = new GraphQLClient('');
  const sdk = getSdk(client);
  
  await sdk.feed();
  await sdk.feed3();
  await sdk.feed4();

  const result = await sdk.feed2({ v: "1" });

  if (result.feed) {
    if (result.feed[0]) {
      const id = result.feed[0].id
    }
  }
}`;
            const output = yield validate(result, config, docs, schema, usage);
            expect(output).toMatchSnapshot();
        }));
    });
});
//# sourceMappingURL=graphql-request.spec.js.map